@@ -25,8 +25,8 @@
 #' @examples
 #' df.1.path <- system.file("examples", "calsc.cq.txt", package = "qPCRtools")
 #' df.2.path <- system.file("examples", "calsc.info.txt", package = "qPCRtools")
-#' df.1 <- data.table::fread(df.1.path)
-#' df.2 <- data.table::fread(df.2.path)
+#' df.1 <- read.table(df.1.path, header = TRUE)
+#' df.2 <- read.table(df.2.path, header = TRUE)
 #' CalCurve(
 #'   cq.table = df.1,
 #'   concen.table = df.2,
@@ -130,8 +130,10 @@ CalCurve <- function(cq.table,
       ggpmisc::stat_poly_eq(
         ggplot2::aes(
           label = paste( # ..eq.label..,
-            ..rr.label..,
-            ..p.value.label..,
+            # ..rr.label..,
+            ggplot2::after_stat(rr.label),
+            ggplot2::after_stat(p.value.label),
+            # ..p.value.label..,
             sep = "~~~~"
           )
         ),
